@@ -1,22 +1,24 @@
 from __future__ import annotations
 
 import sys
-from typing import Any, Awaitable, Callable, Hashable, Iterable, TypeVar, Union
+from typing import Awaitable, Callable, Hashable, Iterable, TypeVar, Union
 
 if sys.version_info < (3, 8):
     from typing_extensions import Protocol
 else:
     from typing import Protocol
 
-from di.api.dependencies import DependantBase
+from di.api.dependencies import DependentBase
 
 StateType = TypeVar("StateType")
-T_co = TypeVar("T_co", covariant=True)
 
 
 class Task(Hashable, Protocol[StateType]):
-    dependant: DependantBase[Any]
-    compute: Union[Callable[[StateType], None], Callable[[StateType], Awaitable[None]]]
+    dependent: DependentBase[StateType]
+
+    @property
+    def compute(self) -> Callable[[StateType], Union[Awaitable[None], None]]:
+        ...
 
 
 class SupportsTaskGraph(Protocol[StateType]):
